# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Matchmaking Service."""

__version__ = "2.18.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .log_app_message_declaration import LogAppMessageDeclaration
from .models_alliance_flexing_rule import ModelsAllianceFlexingRule
from .models_alliance_rule import ModelsAllianceRule
from .models_alliance_rule_v1 import ModelsAllianceRuleV1
from .models_channel import ModelsChannel
from .models_channel_request import ModelsChannelRequest
from .models_channel_v1 import ModelsChannelV1
from .models_combination import ModelsCombination
from .models_combination_alliances import ModelsCombinationAlliances
from .models_create_channel_response import ModelsCreateChannelResponse
from .models_dequeue_request import ModelsDequeueRequest
from .models_flexing_rule import ModelsFlexingRule
from .models_get_channels_response import ModelsGetChannelsResponse
from .models_import_config_response import ModelsImportConfigResponse
from .models_match_add_user_into_session_request import (
    ModelsMatchAddUserIntoSessionRequest,
)
from .models_match_option import ModelsMatchOption
from .models_match_option_rule import ModelsMatchOptionRule
from .models_match_result_request import ModelsMatchResultRequest
from .models_match_result_response import ModelsMatchResultResponse
from .models_matching_ally import ModelsMatchingAlly
from .models_matching_party import ModelsMatchingParty
from .models_matching_rule import ModelsMatchingRule
from .models_matchmaking_result import ModelsMatchmakingResult
from .models_pagination import ModelsPagination
from .models_party_member import ModelsPartyMember
from .models_player_result_request import ModelsPlayerResultRequest
from .models_player_result_response import ModelsPlayerResultResponse
from .models_rebalance_request import ModelsRebalanceRequest
from .models_rebalance_response import ModelsRebalanceResponse
from .models_result_attribute_request import ModelsResultAttributeRequest
from .models_result_attribute_response import ModelsResultAttributeResponse
from .models_rule_set import ModelsRuleSet
from .models_rule_set_v1 import ModelsRuleSetV1
from .models_sub_game_mode import ModelsSubGameMode
from .models_update_alliance_rule import ModelsUpdateAllianceRule
from .models_update_channel_request import ModelsUpdateChannelRequest
from .models_update_play_time_weight_request import ModelsUpdatePlayTimeWeightRequest
from .models_update_player_playtime_weight_response import (
    ModelsUpdatePlayerPlaytimeWeightResponse,
)
from .models_update_ruleset import ModelsUpdateRuleset
from .models_update_ruleset_sub_game_modes import ModelsUpdateRulesetSubGameModes
from .response_error import ResponseError
from .response_error_v1 import ResponseErrorV1
from .service_get_session_history_detailed_response_item import (
    ServiceGetSessionHistoryDetailedResponseItem,
)
from .service_get_session_history_search_response import (
    ServiceGetSessionHistorySearchResponse,
)
from .service_get_session_history_search_response_item import (
    ServiceGetSessionHistorySearchResponseItem,
)
from .service_get_session_history_search_response_item_v2 import (
    ServiceGetSessionHistorySearchResponseItemV2,
)
from .service_get_session_history_search_response_v2 import (
    ServiceGetSessionHistorySearchResponseV2,
)
