# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Session Service."""

__version__ = "2.3.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .apimodels_configuration_template_response import (
    ApimodelsConfigurationTemplateResponse,
)
from .apimodels_configuration_templates_response import (
    ApimodelsConfigurationTemplatesResponse,
)
from .apimodels_create_configuration_template_request import (
    ApimodelsCreateConfigurationTemplateRequest,
)
from .apimodels_create_game_session_request import ApimodelsCreateGameSessionRequest
from .apimodels_create_party_request import ApimodelsCreatePartyRequest
from .apimodels_ds_information_response import ApimodelsDSInformationResponse
from .apimodels_game_session_query_response import ApimodelsGameSessionQueryResponse
from .apimodels_game_session_response import ApimodelsGameSessionResponse
from .apimodels_join_by_code_request import ApimodelsJoinByCodeRequest
from .apimodels_kick_response import ApimodelsKickResponse
from .apimodels_pagination import ApimodelsPagination
from .apimodels_party_query_response import ApimodelsPartyQueryResponse
from .apimodels_party_session_response import ApimodelsPartySessionResponse
from .apimodels_promote_leader_request import ApimodelsPromoteLeaderRequest
from .apimodels_public_configuration import ApimodelsPublicConfiguration
from .apimodels_request_member import ApimodelsRequestMember
from .apimodels_session_invite_request import ApimodelsSessionInviteRequest
from .apimodels_update_configuration_template_request import (
    ApimodelsUpdateConfigurationTemplateRequest,
)
from .apimodels_update_game_session_member_status_response import (
    ApimodelsUpdateGameSessionMemberStatusResponse,
)
from .apimodels_update_game_session_request import ApimodelsUpdateGameSessionRequest
from .apimodels_update_party_request import ApimodelsUpdatePartyRequest
from .apimodels_user_response import ApimodelsUserResponse
from .models_game_server import ModelsGameServer
from .models_team import ModelsTeam
from .response_error import ResponseError
