# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Match Service V2."""

__version__ = "1.4.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_rule_set import CreateRuleSet
from .delete_rule_set import DeleteRuleSet
from .rule_set_details import RuleSetDetails
from .rule_set_list import RuleSetList
from .update_rule_set import UpdateRuleSet
