# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Ds Log Manager Service."""

__version__ = "2.8.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .log_app_message_declaration import LogAppMessageDeclaration
from .models_allocation_event import ModelsAllocationEvent
from .models_batch_download_logs_request import ModelsBatchDownloadLogsRequest
from .models_download_logs_request import ModelsDownloadLogsRequest
from .models_list_terminated_servers_response import ModelsListTerminatedServersResponse
from .models_log_file_status import ModelsLogFileStatus
from .models_match_result import ModelsMatchResult
from .models_notif_payload_server_status_change import (
    ModelsNotifPayloadServerStatusChange,
)
from .models_paging_cursor import ModelsPagingCursor
from .models_request_match_member import ModelsRequestMatchMember
from .models_request_match_party import ModelsRequestMatchParty
from .models_request_matching_ally import ModelsRequestMatchingAlly
from .models_server import ModelsServer
from .models_status_history import ModelsStatusHistory
from .response_error import ResponseError
