# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Legal Service."""

__version__ = "1.25.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_localized_policy_19e4a3 import CreateLocalizedPolicyVersion
from .request_presigned_url import RequestPresignedURL
from .retrieve_localized_poli_24a671 import RetrieveLocalizedPolicyVersions
from .retrieve_single_localiz_2f6231 import RetrieveSingleLocalizedPolicyVersion
from .retrieve_single_localiz_f21ac4 import RetrieveSingleLocalizedPolicyVersion1
from .set_default_policy import SetDefaultPolicy
from .update_localized_policy_a8a90f import UpdateLocalizedPolicyVersion
